@@ -1,17 +1,15 @@
 package Protocol::XMPP::Contact;
-$Protocol::XMPP::Contact::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw{Protocol::XMPP::Base};
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 Protocol::XMPP::Stream - handle XMPP protocol stream
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 METHODS
 
 =cut
@@ -20,8 +18,8 @@ sub jid { shift->{jid} }
 sub name { my $self = shift; defined($self->{name}) ? $self->{name} : $self->{jid} }
 
 sub is_me {
-	my $self = shift;
-	return $self->jid eq $self->stream->jid;
+  my $self = shift;
+  return $self->jid eq $self->stream->jid;
 }
 
 =head2 authorise
@@ -31,8 +29,8 @@ Authorise a contact by sending a 'subscribed' presence response.
 =cut
 
 sub authorise {
-	my $self = shift;
-	$self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'subscribed']);
+  my $self = shift;
+  $self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'subscribed']);
 }
 
 =head2 subscribe
@@ -42,8 +40,8 @@ Request subscription for a contact by sending a 'subscribe' presence response.
 =cut
 
 sub subscribe {
-	my $self = shift;
-	$self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'subscribe']);
+  my $self = shift;
+  $self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'subscribe']);
 }
 
 =head2 unsubscribe
@@ -53,8 +51,8 @@ Reject or unsubscribe a contact by sending an 'unsubscribed' presence response.
 =cut
 
 sub unsubscribe {
-	my $self = shift;
-	$self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'unsubscribed']);
+  my $self = shift;
+  $self->write_xml(['presence', from => $self->stream->jid, to => $self->jid, type => 'unsubscribed']);
 }
 
 1;
@@ -63,8 +61,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
+
