@@ -1,17 +1,15 @@
 package Protocol::XMPP::Element::IQ;
-$Protocol::XMPP::Element::IQ::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 Protocol::XMPP::Bind - register ability to deal with a specific feature
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -25,10 +23,10 @@ Version 0.006
 =cut
 
 sub end_element {
-	my $self = shift;
-	$self->debug("IQ data");
-	my $id = $self->attributes->{id};
-	$self->stream->iq_complete($id => $self);
+  my $self = shift;
+  $self->debug("IQ data");
+  my $id = $self->attributes->{id};
+  $self->stream->iq_complete($id => $self);
 }
 
 1;
@@ -37,8 +35,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
+
