@@ -1,17 +1,15 @@
 package Protocol::XMPP::Element::Proceed;
-$Protocol::XMPP::Element::Proceed::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 =head1 SYNOPSIS
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -19,9 +17,9 @@ Version 0.006
 =cut
 
 sub end_element {
-	my $self = shift;
-	$self->dispatch_event('starttls');
-	$self;
+  my $self = shift;
+  $self->dispatch_event('starttls');
+  $self;
 }
 
 1;
@@ -30,8 +28,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
+
