@@ -1,17 +1,15 @@
 package Protocol::XMPP::Element::Response;
-$Protocol::XMPP::Element::Response::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 =head1 SYNOPSIS
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 DESCRIPTION
 
 =head1 METHODS
@@ -24,8 +22,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
+
