@@ -1,17 +1,15 @@
 package Protocol::XMPP::Element::Stream;
-$Protocol::XMPP::Element::Stream::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 Protocol::XMPP::Element::Stream - handle the stream start/end tags
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -21,10 +19,10 @@ Version 0.006
 =cut
 
 sub new {
-	my $class = shift;
-	my $self = $class->SUPER::new(@_);
-	$self->stream->remote_opened->done;
-	$self
+  my $class = shift;
+  my $self = $class->SUPER::new(@_);
+  $self->stream->remote_opened->done;
+  $self
 }
 
 =head2 C<end_element>
@@ -32,8 +30,8 @@ sub new {
 =cut
 
 sub end_element {
-	my $self = shift;
-	$self->stream->remote_closed->done;
+  my $self = shift;
+  $self->stream->remote_closed->done;
 }
 
 1;
@@ -42,8 +40,8 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
