@@ -1,17 +1,15 @@
 package Protocol::XMPP::ElementBase;
-$Protocol::XMPP::ElementBase::VERSION = '0.006';
+
 use strict;
 use warnings;
 use parent qw{Protocol::XMPP::Base};
 
+our $VERSION = '0.007'; ## VERSION
+
 =head1 NAME
 
 Protocol::XMPP::ElementBase - base class for L<Protocol::XMPP> XML fragment handling
 
-=head1 VERSION
-
-Version 0.006
-
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
@@ -21,10 +19,10 @@ Version 0.006
 =cut
 
 sub new {
-	my $class = shift;
-	my $self = $class->SUPER::new(@_);
-	$self->{data} = '';
-	return $self;
+  my $class = shift;
+  my $self = $class->SUPER::new(@_);
+  $self->{data} = '';
+  return $self;
 }
 
 =head2 attributes
@@ -34,10 +32,10 @@ Access the XML element attributes as key-value pairs.
 =cut
 
 sub attributes {
-	my $self = shift;
-	return {
-		map { $_->{LocalName} => $_->{Value} } values %{$self->{element}->{Attributes}}
-	};
+  my $self = shift;
+  return {
+    map { $_->{LocalName} => $_->{Value} } values %{$self->{element}->{Attributes}}
+  };
 }
 
 =head2 parent
@@ -55,10 +53,10 @@ Called when new character data is available. Appends to internal buffer.
 =cut
 
 sub characters {
-	my $self = shift;
-	my $data = shift;
-	$self->{data} .= $data;
-	$self;
+  my $self = shift;
+  my $data = shift;
+  $self->{data} .= $data;
+  $self;
 }
 
 =head2 end_element
@@ -68,8 +66,8 @@ Called when an XML element is terminated.
 =cut
 
 sub end_element {
-	my $self = shift;
-	$self->debug("Virtual end_element for $_[0]");
+  my $self = shift;
+  $self->debug("Virtual end_element for $_[0]");
 }
 
 =head2 class_from_element
@@ -89,8 +87,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@entitymodel.com>
+Tom Molesworth <tom@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2010-2026. Licensed under the same terms as Perl itself.
+
